.onAttach = function(...){
  packageStartupMessage("This is `geosimilarity` 3.0.
                        \nTo cite `geosimilarity` in publications, please use:
                        \nSong, Y. (2022). Geographically Optimal Similarity. Mathematical Geosciences. doi: 10.1007/s11004-022-10036-8.
                        ")
}
